@@ -6,7 +6,7 @@ from collections import deque
 from json import dumps
 from pathlib import Path
 from pprint import pformat
-from signal import signal, SIGTERM, SIGUSR1, SIGTSTP, SIGCONT
+from signal import signal, Signals, SIGTERM, SIGUSR1, SIGTSTP, SIGCONT
 from subprocess import Popen
 from threading import Event, Thread
 from syslog import syslog, LOG_ERR, LOG_INFO, LOG_WARNING
@@ -109,7 +109,7 @@ class CheckI3StatusThread(Task):
             self.notify_user(err)
         else:
             # check again in 5 seconds
-            self.timeout_queue_add(self, int(time.perf_counter()) + 5)
+            self.timeout_queue_add(self, int(time.monotonic()) + 5)
 
 
 class ModuleRunner(Task):
@@ -251,8 +251,10 @@ class Py3statusWrapper:
         """
         self.config = vars(options)
         self.i3bar_running = True
-        self.i3bar_inhibit_stp = time.time()
-        self.last_refresh_ts = time.perf_counter()
+        self.last_loop_ts = time.monotonic()
+        self.last_refresh_ts = time.monotonic()
+        self.last_sigcont_ts = None
+        self.last_sigtstp_ts = None
         self.lock = Event()
         self.modules = {}
         self.notified_messages = set()
@@ -260,6 +262,7 @@ class Py3statusWrapper:
         self.output_modules = {}
         self.py3_modules = []
         self.running = True
+        self.stop_signal = SIGTSTP
         self.update_queue = deque()
         self.update_request = Event()
 
@@ -276,6 +279,7 @@ class Py3statusWrapper:
         self.timeout_missed = {}
         self.timeout_queue = {}
         self.timeout_queue_lookup = {}
+        self.timeout_queue_lookup_previous = {}
         self.timeout_running = set()
         self.timeout_update_due = deque()
 
@@ -292,6 +296,25 @@ class Py3statusWrapper:
         if self.timeout_due is None or cache_time < self.timeout_due:
             self.update_request.set()
 
+    def clear_timeout_due(self, module):
+        old = self.timeout_queue_lookup_previous.get(module, None)
+        if old:
+            if old == self.timeout_due:
+                self._set_new_timeout_due()
+            elif old in self.timeout_keys:
+                self.timeout_keys.remove(old)
+                self._set_new_timeout_due()
+
+    def _set_new_timeout_due(self):
+        # sort keys so earliest is first
+        self.timeout_keys.sort()
+
+        # when is next timeout due?
+        try:
+            self.timeout_due = self.timeout_keys[0]
+        except IndexError:
+            self.timeout_due = None
+
     def timeout_process_add_queue(self, module, cache_time):
         """
         Add a module to the timeout_queue if it is scheduled in the future or
@@ -308,7 +331,7 @@ class Py3statusWrapper:
             return
 
         # remove if already in the queue
-        key = self.timeout_queue_lookup.get(module)
+        key = self.timeout_queue_lookup.get(module, None)
         if key:
             queue_item = self.timeout_queue[key]
             queue_item.remove(module)
@@ -319,24 +342,20 @@ class Py3statusWrapper:
         if cache_time == 0:
             # if cache_time is 0 we can just trigger the module update
             self.timeout_update_due.append(module)
-            self.timeout_queue_lookup[module] = None
+            if module in self.timeout_queue_lookup.keys():
+                del self.timeout_queue_lookup[module]
         else:
             # add the module to the timeout queue
             if cache_time not in self.timeout_keys:
                 self.timeout_queue[cache_time] = {module}
                 self.timeout_keys.append(cache_time)
-                # sort keys so earliest is first
-                self.timeout_keys.sort()
 
-                # when is next timeout due?
-                try:
-                    self.timeout_due = self.timeout_keys[0]
-                except IndexError:
-                    self.timeout_due = None
+                self._set_new_timeout_due()
             else:
                 self.timeout_queue[cache_time].add(module)
             # note that the module is in the timeout_queue
             self.timeout_queue_lookup[module] = cache_time
+            self.timeout_queue_lookup_previous[module] = cache_time
 
     def timeout_queue_process(self):
         """
@@ -345,7 +364,7 @@ class Py3statusWrapper:
         # process any items that need adding to the queue
         while self.timeout_add_queue:
             self.timeout_process_add_queue(*self.timeout_add_queue.popleft())
-        now = time.perf_counter()
+        now = time.monotonic()
         due_timeouts = []
         # find any due timeouts
         for timeout in self.timeout_keys:
@@ -402,8 +421,9 @@ class Py3statusWrapper:
                 Runner(module, self, module_name)
 
         # we return how long till we next need to process the timeout_queue
+        # this value should not be negative to avoid cpu overwhelming loops
         if self.timeout_due is not None:
-            return self.timeout_due - time.perf_counter()
+            return max(0, self.timeout_due - time.monotonic())
 
     def gevent_monkey_patch_report(self):
         """
@@ -527,14 +547,6 @@ class Py3statusWrapper:
         Setup py3status and spawn i3status/events/modules threads.
         """
 
-        # SIGTSTP will be received from i3bar indicating that all output should
-        # stop and we should consider py3status suspended.  It is however
-        # important that any processes using i3 ipc should continue to receive
-        # those events otherwise it can lead to a stall in i3.
-        signal(SIGTSTP, self.i3bar_stop)
-        # SIGCONT indicates output should be resumed.
-        signal(SIGCONT, self.i3bar_start)
-
         # log py3status and python versions
         self.log("=" * 8)
         msg = "Starting py3status version {version} python {python_version}"
@@ -641,6 +653,35 @@ class Py3statusWrapper:
             sys.stdout = Path("/dev/null").open("w")
             sys.stderr = Path("/dev/null").open("w")
 
+        # make sure we honor custom i3bar protocol stop/resume signals
+        # while providing users a way to opt out from that feature
+        # using the 0 value as specified by the i3bar protocol
+        custom_stop_signal = (
+            self.config["py3_config"].get("py3status", {}).get("stop_signal")
+        )
+        if custom_stop_signal is not None:
+            try:
+                # 0 is a special value for i3bar protocol, use it as-is
+                if custom_stop_signal == 0:
+                    self.stop_signal = custom_stop_signal
+                else:
+                    self.stop_signal = Signals(custom_stop_signal)
+            except ValueError:
+                error = (
+                    f"py3status.stop_signal '{custom_stop_signal}' is invalid "
+                    f"and should be a number between 0 (disable) and 31"
+                )
+                self.log(error, level="error")
+                raise Exception(error)
+
+        # SIGTSTP can be received and indicates that all output should
+        # stop and we should consider py3status suspended.  It is however
+        # important that any processes using i3 ipc should continue to receive
+        # those events otherwise it can lead to a stall in i3.
+        signal(SIGTSTP, self.i3bar_stop)
+        # SIGCONT indicates output should be resumed.
+        signal(SIGCONT, self.i3bar_start)
+
         # get the list of py3status configured modules
         self.py3_modules = self.config["py3_config"]["py3_modules"]
 
@@ -690,7 +731,7 @@ class Py3statusWrapper:
         limit_key = ""
         if rate_limit:
             try:
-                limit_key = time.perf_counter() // rate_limit
+                limit_key = time.monotonic() // rate_limit
             except TypeError:
                 pass
         # We use a hash to see if the message is being repeated.  This is crude
@@ -765,8 +806,8 @@ class Py3statusWrapper:
         refreshes.
         """
         if not module_string:
-            if time.perf_counter() > (self.last_refresh_ts + 0.1):
-                self.last_refresh_ts = time.perf_counter()
+            if time.monotonic() > (self.last_refresh_ts + 0.1):
+                self.last_refresh_ts = time.monotonic()
             else:
                 # rate limiting
                 return
@@ -951,18 +992,25 @@ class Py3statusWrapper:
         return ",".join(dumps(x) for x in outputs)
 
     def i3bar_stop(self, signum, frame):
-        if time.time() - self.i3bar_inhibit_stp > 1:
-            self.log("received SIGTSTP")
+        if (
+            self.last_sigcont_ts
+            and self.last_sigtstp_ts
+            and self.last_sigcont_ts > self.last_sigtstp_ts
+            and time.monotonic() - self.last_loop_ts < 1
+        ):
+            self.log(f"received stop_signal {Signals(signum).name}")
             self.i3bar_running = False
             # i3status should be stopped
             self.i3status_thread.suspend_i3status()
             self.sleep_modules()
         else:
-            self.log("received inhibited SIGTSTP")
+            self.log(f"inhibited stop_signal {Signals(signum).name}", level="warning")
+        self.last_sigtstp_ts = time.monotonic()
 
     def i3bar_start(self, signum, frame):
-        self.log("received SIGCONT")
-        self.i3bar_inhibit_stp = time.time()
+        self.log(f"received resume signal {Signals(signum).name}")
+        self.last_loop_ts = time.monotonic()
+        self.last_sigcont_ts = time.monotonic()
         self.i3bar_running = True
         self.wake_modules()
 
@@ -1016,7 +1064,7 @@ class Py3statusWrapper:
         header = {
             "version": 1,
             "click_events": self.config["click_events"],
-            "stop_signal": SIGTSTP,
+            "stop_signal": self.stop_signal or 0,
         }
         write(dumps(header))
         write("\n[[]\n")
@@ -1035,6 +1083,8 @@ class Py3statusWrapper:
             while not self.i3bar_running:
                 time.sleep(0.1)
 
+            self.last_loop_ts = time.monotonic()
+
             # check if an update is needed
             if self.update_queue:
                 while len(self.update_queue):
