@@ -156,9 +156,10 @@ no_mail
 """
 
 import mailbox
+import os
 from csv import reader
 from imaplib import IMAP4_SSL, IMAP4
-from os.path import exists, expanduser, expandvars
+from pathlib import Path
 
 STRING_MISSING = "missing {} {}"
 STRING_INVALID_NAME = "invalid name `{}`"
@@ -167,8 +168,7 @@ STRING_INVALID_FILTER = "invalid imap filters `{}`"
 
 
 class Py3status:
-    """
-    """
+    """"""
 
     # available configuration parameters
     accounts = {}
@@ -215,9 +215,11 @@ class Py3status:
                         if mail == box.lower():
                             if "path" not in account:
                                 raise Exception(STRING_MISSING.format(mail, "path"))
-                            path = expandvars(expanduser(account["path"]))
-                            if not exists(path):
-                                path = "path: {}".format(path)
+                            path = os.path.expandvars(
+                                Path(account["path"]).expanduser()
+                            )
+                            if not path.exists():
+                                path = f"path: {path}"
                                 raise Exception(STRING_MISSING.format(mail, path))
                             account["box"] = box
                             account["path"] = path
@@ -241,7 +243,7 @@ class Py3status:
                         filters = "|".join(account.pop("filters"))
                         objs = [x.decode() for x in inbox.list()[1]]
                         folders = [x[-1] for x in reader(objs, delimiter=" ")]
-                        lines = ["===== IMAP {} =====".format(i)]
+                        lines = [f"===== IMAP {i} ====="]
                         for name in folders:
                             subscribed = " "
                             try:
@@ -249,12 +251,12 @@ class Py3status:
                                     subscribed = "x"
                                     folder = name.replace("\\", "\\\\")
                                     folder = folder.replace('"', '\\"')
-                                    folder = '"{}"'.format(folder)
+                                    folder = f'"{folder}"'
                                     account["folders"].append(folder)
                             except re.error:
                                 account["folders"] = []
                                 break
-                            lines.append("[{}] {}".format(subscribed, name))
+                            lines.append(f"[{subscribed}] {name}")
                         if not account["folders"]:
                             self.py3.error(
                                 STRING_INVALID_FILTER.format(filters),
@@ -286,7 +288,7 @@ class Py3status:
                     mail_data[account["name"]] = count_mail
                 if account["urgent"] and count_mail:
                     mail_data["urgent"] = True
-                mail_data["{}_{}".format(k, i)] = count_mail
+                mail_data[f"{k}_{i}"] = count_mail
                 mail_data["mail"] += count_mail
                 mail_data[k] += count_mail
 
