@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Display network and IP address for newer Huwei modems.
 
@@ -56,9 +55,9 @@ off
 """
 
 import netifaces as ni
-import os
 import stat
 import serial
+from pathlib import Path
 from time import sleep
 
 
@@ -93,14 +92,15 @@ class Py3status:
         response["cached_until"] = self.py3.time_in(self.cache_timeout)
 
         # Check if path exists and is a character device
-        if os.path.exists(self.modem) and stat.S_ISCHR(os.stat(self.modem).st_mode):
+        modem_path = Path(self.modem)
+        if modem_path.exists() and stat.S_ISCHR(modem_path.stat().st_mode):
             print("Found modem " + self.modem)
             try:
                 ser = serial.Serial(
                     port=self.modem,
                     baudrate=self.baudrate,
                     # Values below work for my modem. Not sure if
-                    # they neccessarily work for all modems
+                    # they necessarily work for all modems
                     parity=serial.PARITY_ODD,
                     stopbits=serial.STOPBITS_ONE,
                     bytesize=serial.EIGHTBITS,
